Struct pychan::py_bytes::PyBytesSender
source · pub struct PyBytesSender { /* private fields */ }Trait Implementations
sourceimpl Clone for PyBytesSender
impl Clone for PyBytesSender
sourcefn clone(&self) -> PyBytesSender
fn clone(&self) -> PyBytesSender
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl HasPyGilRef for PyBytesSender
impl HasPyGilRef for PyBytesSender
type AsRefTarget = PyCell<PyBytesSender>
type AsRefTarget = PyCell<PyBytesSender>
Utility type to make Py::as_ref work.
sourceimpl PyAddToModule for PyBytesSender
impl PyAddToModule for PyBytesSender
sourceimpl PyClassImpl for PyBytesSender
impl PyClassImpl for PyBytesSender
sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
type ThreadChecker = SendablePyClass<PyBytesSender>
type ThreadChecker = SendablePyClass<PyBytesSender>
This handles following two situations: Read more
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
type BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a PyBytesSender
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a PyBytesSender
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut PyBytesSender
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut PyBytesSender
sourceimpl PyTypeInfo for PyBytesSender
impl PyTypeInfo for PyBytesSender
sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
sourcefn type_object(py: Python<'_>) -> &PyType
fn type_object(py: Python<'_>) -> &PyType
👎Deprecated since 0.21.0:
PyTypeInfo::type_object will be replaced by PyTypeInfo::type_object_bound in a future PyO3 versionReturns the safe abstraction over the type object.
sourcefn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
fn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
sourcefn is_type_of(object: &PyAny) -> bool
fn is_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_type_of will be replaced by PyTypeInfo::is_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type or a subclass of this type.sourcefn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
fn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.sourcefn is_exact_type_of(object: &PyAny) -> bool
fn is_exact_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_exact_type_of will be replaced by PyTypeInfo::is_exact_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type.sourceimpl Sink<Py<PyBytes>> for PyBytesSender
impl Sink<Py<PyBytes>> for PyBytesSender
type Error = <PySender<PyBytes> as Sink<Py<PyBytes>>>::Error
type Error = <PySender<PyBytes> as Sink<Py<PyBytes>>>::Error
The type of value produced by the sink when an error occurs.
sourcefn poll_ready(
self: Pin<&mut Self>,
cx: &mut Context<'_>
) -> Poll<Result<(), Self::Error>>
fn poll_ready( self: Pin<&mut Self>, cx: &mut Context<'_> ) -> Poll<Result<(), Self::Error>>
Attempts to prepare the
Sink to receive a value. Read moresourcefn start_send(
self: Pin<&mut Self>,
item: Py<PyBytes>
) -> Result<(), Self::Error>
fn start_send( self: Pin<&mut Self>, item: Py<PyBytes> ) -> Result<(), Self::Error>
Begin the process of sending a value to the sink.
Each call to this function must be preceded by a successful call to
poll_ready which returned Poll::Ready(Ok(())). Read moreimpl DerefToPyAny for PyBytesSender
impl<'pin> Unpin for PyBytesSenderwhere
__PyBytesSender<'pin>: Unpin,